import { lambdaRoute } from './types/lambdaRoute';
export * from './types/lambdaRoute';
/**
 * The definition of routes to host.
 *
 * @export
 * @interface RouteConfig
 */
export interface RouteConfig {
    routes: Array<lambdaRoute>;
}
/**
 * The server.
 *
 * @class Server
 */
export declare class Server {
    private app;
    private port;
    private router;
    private auth_service;
    /**
     * Constructor.
     *
     * @class Server
     * @constructor
     */
    constructor();
    /**
     * Configure the server.  You should only call this once.
     *
     * @param {Array<lambdaRoute>} routes The list of routes to host.
     * @param {*} corsOptions Optional CORS configuration.
     * @memberof Server
     */
    config(routes: Array<lambdaRoute>, corsOptions?: any): void;
    /**
     * Begin listening for requests on the specified port.
     *
     * @param {number} port The port # to listen on.
     * @param {() => void} [callback] Optional callback method to be called upon port attachment.
     * @memberof Server
     */
    listen(port: number, callback?: () => void): void;
}
